<?php

$dir = '/api/includes/reports';

class ReplicationCapacityReport
{
    private $BP;

    public function __construct( $BP, $functionsClass )
    {
        $this->BP = $BP;
        $this->functions = $functionsClass;
    }

    public function get_replication_capacity_report($sid, $data)
    {
        $targetSelected = false;
        $localSystemID = $this->BP->get_local_system_id();
        if ($sid === $localSystemID) {
            // If the target is selected, get all replicating assets, summarizing size per appliance.
            $sid = false;
            $targetSelected = true;
        }
        $systems = $this->functions->selectReplicatingSystems($sid);

        $report = array();
        $report_count = 0;
        //Temporary until more data is available
        $report_total = $report_count;
        $report_start = 1;
        $report_data = array();

        foreach ($systems as $system_id => $system_name)
        {
            $system_size = 0;
            // Get retention for all replicated assets on this target, per source/system_id
            $retentionInfoList = $this->BP->get_grandclient_retention_info(array('system_id' => $system_id));
            if ($retentionInfoList !== false)
            {
                foreach ($retentionInfoList as $retentionInfo)
                {
                    if (isset($retentionInfo['app_name']) && isset($retentionInfo['instance_id'])) {
                        $appName = $retentionInfo['app_name'];
                        if ($appName !== Constants::APPLICATION_TYPE_NAME_SYSTEM_METADATA) {
                            // Not including Appliance Metadata in the capacity report.
                            $instanceID = $retentionInfo['instance_id'];
                            $instanceInfo = $this->functions->getInstanceNames($instanceID, $localSystemID);
                            if ($instanceInfo !== false) {
                                $instanceName = $instanceInfo['asset_name'];
                                $clientName = $instanceInfo['client_name'];
                                if (!$targetSelected) {
                                    $report_data[] = $this->buildReplicationCapacityPerInstance($appName,
                                        $clientName,
                                        $retentionInfo['mb_size'],
                                        $system_name,
                                        $instanceName);
                                    $report_count += 1;                                    
                                } else {
                                    $system_size += $retentionInfo['mb_size'];
                                }
                            }
                        }
                    }
                }
                if ($targetSelected) {
                    // Output one summary record per replicating source.
                    $report_data[] = $this->buildReplicationCapacityPerInstance('',
                        'All',
                        $system_size,
                        $system_name,
                        'All');
                    $report_count += 1;
                }
            } else {
                // Output a row with any system that fails the retention info call.
                $message = $this->BP->getError();
                $report_data[] = $this->buildReplicationCapacityPerInstance($message, 'unavailable', '', $system_name);
                $report_count += 1;
            }
        }
        $report_total = $report_count;  //Temporary

        $report['count'] = $report_count;
        $report['total'] = $report_total;
        $report['start'] = $report_start;
        $report['data'] = $report_data;
        return $report;

    }

    private function buildReplicationCapacityPerInstance( $appName, $clientName, $size, $systemName, $instanceName = '', $databaseName = '')
    {
        $replication_capacity_info = array();
        $replication_capacity_info['app_name'] = $appName;
        $replication_capacity_info['client_name'] = $clientName;
        $replication_capacity_info['instance_name'] = $instanceName;
        $replication_capacity_info['database_name'] = $databaseName;
        $replication_capacity_info['size'] = $size;
        $replication_capacity_info['system_name'] = $systemName;
        //$replication_capacity_info['retention_policy'] = 'CoreWorkNeeded'; //Not available for 1st Out
        //$replication_capacity_info['retention_id'] = 0; //Not available for 1st Out

        return $replication_capacity_info;
    }

}
